Installation - flarchitect
Description: Install couldn’t be easier. Just install with pip.

Hide navigation sidebar
Hide table of contents sidebar
flarchitect

Contents:

- Installation
- Quick Start
- SQLAlchemy Models
- Authentication
- Callbacks
- Configuration
  Toggle navigation of Configuration
  - Config Globals
  - Config by Method Globals
  - Config Models
  - Config by Method Models
- FAQ
- Index

Back to top
Toggle table of contents sidebar

# Installation

Install couldn’t be easier. Just install with pip.

    $ pip install flarchitect